@@ -118,7 +118,10 @@ class LabelModel(_AbstractRateModel, BaseModel):
         ['cpd__00', 'cpd__01', 'cpd__10', 'cpd__11']
         """
         if num_labels > 0:
-            return [base_name + "__" + "".join(i) for i in it.product(("0", "1"), repeat=num_labels)]
+            return [
+                base_name + "__" + "".join(i)
+                for i in it.product(("0", "1"), repeat=num_labels)
+            ]
         return [base_name]
 
     def add_compound(  # type: ignore
@@ -179,7 +182,9 @@ class LabelModel(_AbstractRateModel, BaseModel):
             parameters=None,
         )
 
-    def add_label_compound(self, compound: str, num_labels: int, **meta_info: Dict[str, Any]) -> None:
+    def add_label_compound(
+        self, compound: str, num_labels: int, **meta_info: Dict[str, Any]
+    ) -> None:
         """Create all label isotopomers and add them as compounds.
 
         Also create an algebraic module that tracks the total
@@ -207,7 +212,9 @@ class LabelModel(_AbstractRateModel, BaseModel):
                 **meta_info,  # type: ignore
             )
         else:
-            label_names = self._generate_binary_labels(base_name=compound, num_labels=num_labels)
+            label_names = self._generate_binary_labels(
+                base_name=compound, num_labels=num_labels
+            )
             self._add_base_compound(
                 base_compound=compound,
                 num_labels=num_labels,
@@ -280,7 +287,9 @@ class LabelModel(_AbstractRateModel, BaseModel):
         """Get all isotopomers of a compound."""
         return list(self.label_compounds[compound]["isotopomers"])
 
-    def get_compound_isotopomers_with_n_labels(self, compound: str, n_labels: int) -> List[str]:
+    def get_compound_isotopomers_with_n_labels(
+        self, compound: str, n_labels: int
+    ) -> List[str]:
         """Get all isotopomers of a compound, that have excactly n labels."""
         label_positions = self.label_compounds[compound]["num_labels"]
         label_patterns = [
@@ -348,7 +357,9 @@ class LabelModel(_AbstractRateModel, BaseModel):
         return "".join([rate_suffix[i] for i in labelmap])
 
     @staticmethod
-    def _unpack_stoichiometries(*, stoichiometries: Dict[str, int]) -> Tuple[List[str], List[str]]:
+    def _unpack_stoichiometries(
+        *, stoichiometries: Dict[str, int]
+    ) -> Tuple[List[str], List[str]]:
         """Split stoichiometries into substrates and products.
 
         Parameters
@@ -380,12 +391,16 @@ class LabelModel(_AbstractRateModel, BaseModel):
                 labels_per_compound.append(self.label_compounds[compound]["num_labels"])
             except KeyError as e:
                 if compound not in self.get_compounds():
-                    raise KeyError(f"Compound {compound} neither a compound nor a label compound") from e
+                    raise KeyError(
+                        f"Compound {compound} neither a compound nor a label compound"
+                    ) from e
                 labels_per_compound.append(0)
         return labels_per_compound
 
     @staticmethod
-    def _repack_stoichiometries(*, new_substrates: List[str], new_products: List[str]) -> Dict[str, float]:
+    def _repack_stoichiometries(
+        *, new_substrates: List[str], new_products: List[str]
+    ) -> Dict[str, float]:
         """Pack substrates and products into stoichiometric dict."""
         new_stoichiometries: defaultdict[str, int] = defaultdict(int)
         for arg in new_substrates:
@@ -395,7 +410,9 @@ class LabelModel(_AbstractRateModel, BaseModel):
         return dict(new_stoichiometries)
 
     @staticmethod
-    def _assign_compound_labels(*, base_compounds: List[str], label_suffixes: List[str]) -> List[str]:
+    def _assign_compound_labels(
+        *, base_compounds: List[str], label_suffixes: List[str]
+    ) -> List[str]:
         """Assign the correct suffixes."""
         new_compounds = []
         for i, compound in enumerate(base_compounds):
@@ -467,11 +484,18 @@ class LabelModel(_AbstractRateModel, BaseModel):
         >>> )
         """
         if compounds is not None:
-            compounds = [i + "__total" if i in self.label_compounds else i for i in compounds]
+            compounds = [
+                i + "__total" if i in self.label_compounds else i for i in compounds
+            ]
         if modifiers is not None:
-            modifiers = [i + "__total" if i in self.label_compounds else i for i in modifiers]
+            modifiers = [
+                i + "__total" if i in self.label_compounds else i for i in modifiers
+            ]
         if dynamic_variables is not None:
-            dynamic_variables = [i + "__total" if i in self.label_compounds else i for i in dynamic_variables]
+            dynamic_variables = [
+                i + "__total" if i in self.label_compounds else i
+                for i in dynamic_variables
+            ]
         if args is not None:
             args = [i + "__total" if i in self.label_compounds else i for i in args]
         super().add_algebraic_module(
@@ -635,10 +659,14 @@ class LabelModel(_AbstractRateModel, BaseModel):
         labels_per_product: List[int],
     ) -> List[str]:
         variants = []
-        for rate_suffix in ("".join(i) for i in it.product(("0", "1"), repeat=total_substrate_labels)):
+        for rate_suffix in (
+            "".join(i) for i in it.product(("0", "1"), repeat=total_substrate_labels)
+        ):
             rate_suffix += external_labels
             # This is the magic
-            product_suffix = self._map_substrates_to_products(rate_suffix=rate_suffix, labelmap=labelmap)
+            product_suffix = self._map_substrates_to_products(
+                rate_suffix=rate_suffix, labelmap=labelmap
+            )
             product_labels = self._split_label_string(
                 label=product_suffix, labels_per_compound=labels_per_product
             )
@@ -729,16 +757,22 @@ class LabelModel(_AbstractRateModel, BaseModel):
             )
         """
         if modifiers is not None:
-            modifiers = [i + "__total" if i in self.label_compounds else i for i in modifiers]
+            modifiers = [
+                i + "__total" if i in self.label_compounds else i for i in modifiers
+            ]
 
-        base_substrates, base_products = self._unpack_stoichiometries(stoichiometries=stoichiometry)
+        base_substrates, base_products = self._unpack_stoichiometries(
+            stoichiometries=stoichiometry
+        )
         labels_per_substrate = self._get_labels_per_compound(compounds=base_substrates)
         labels_per_product = self._get_labels_per_compound(compounds=base_products)
         total_substrate_labels = sum(labels_per_substrate)
         total_product_labels = sum(labels_per_product)
 
         if len(labelmap) - total_substrate_labels < 0:
-            raise ValueError(f"Labelmap 'missing' {abs(len(labelmap) - total_substrate_labels)} label(s)")
+            raise ValueError(
+                f"Labelmap 'missing' {abs(len(labelmap) - total_substrate_labels)} label(s)"
+            )
 
         external_label_str = self._get_external_labels(
             rate_name=rate_name,
@@ -901,7 +935,9 @@ class LabelModel(_AbstractRateModel, BaseModel):
             label_position = label_positions.get(base_compound, None)
             if label_position is None:
                 try:
-                    y0[self.label_compounds[base_compound]["isotopomers"][0]] = concentration
+                    y0[
+                        self.label_compounds[base_compound]["isotopomers"][0]
+                    ] = concentration
                 except KeyError:  # non label compound
                     y0[base_compound] = concentration
             else:
@@ -1108,13 +1144,16 @@ class LabelModel(_AbstractRateModel, BaseModel):
             if not module_name.endswith("__total"):
                 module_ = dict(module)
                 module_["compounds"] = [
-                    self._map_label_compound_to_compound(compound=i) for i in module["compounds"]
+                    self._map_label_compound_to_compound(compound=i)
+                    for i in module["compounds"]
                 ]
                 module_["derived_compounds"] = [
-                    self._map_label_compound_to_compound(compound=i) for i in module["derived_compounds"]
+                    self._map_label_compound_to_compound(compound=i)
+                    for i in module["derived_compounds"]
                 ]
                 module_["modifiers"] = [
-                    self._map_label_compound_to_compound(compound=i) for i in module["modifiers"]
+                    self._map_label_compound_to_compound(compound=i)
+                    for i in module["modifiers"]
                 ]
                 m.add_algebraic_module(module_name=module_name, **module_)
 
@@ -1125,7 +1164,8 @@ class LabelModel(_AbstractRateModel, BaseModel):
                 for k, v in reaction["stoichiometry"].items()
             }
             reaction["modifiers"] = [
-                self._map_label_compound_to_compound(compound=i) for i in reaction["modifiers"]
+                self._map_label_compound_to_compound(compound=i)
+                for i in reaction["modifiers"]
             ]
             del reaction["labelmap"]
             del reaction["external_labels"]
