@@ -84,7 +84,9 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
             return None
         return cast(Array, res.values)
 
-    def get_all_isotopomer_concentrations_dict(self, compound: str) -> Optional[Dict[str, Array]]:
+    def get_all_isotopomer_concentrations_dict(
+        self, compound: str
+    ) -> Optional[Dict[str, Array]]:
         """Get concentrations of all isotopomers of a compound."""
         res = self.get_all_isotopomer_concentrations_df(compound=compound)
         if res is None:
@@ -114,7 +116,9 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
         df = cast(pd.DataFrame, df)[isotopomers]
         return cast(Array, df[isotopomers].values)
 
-    def get_concentrations_by_reg_exp_dict(self, reg_exp: str) -> Optional[Dict[str, Array]]:
+    def get_concentrations_by_reg_exp_dict(
+        self, reg_exp: str
+    ) -> Optional[Dict[str, Array]]:
         """Get concentrations of all isotopomers of a compound."""
         isotopomers = [i for i in self.model.get_compounds() if re.match(reg_exp, i)]
         df = self.get_results_df(concatenated=True)
@@ -148,9 +152,13 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
             return None
         return cast(Array, np.sum(res, axis=1))
 
-    def get_concentrations_of_n_labeled_array(self, compound: str, n_labels: int) -> Optional[Array]:
+    def get_concentrations_of_n_labeled_array(
+        self, compound: str, n_labels: int
+    ) -> Optional[Array]:
         """Get concentrations of all isotopomers that carry n labels."""
-        res = self.get_concentrations_of_n_labeled_df(compound=compound, n_labels=n_labels)
+        res = self.get_concentrations_of_n_labeled_df(
+            compound=compound, n_labels=n_labels
+        )
         if res is None:
             return None
         return cast(Array, res.values)
@@ -164,7 +172,9 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
             return None
         return dict(zip(df.columns, df.values.T))
 
-    def get_concentrations_of_n_labeled_df(self, compound: str, n_labels: int) -> Optional[pd.DataFrame]:
+    def get_concentrations_of_n_labeled_df(
+        self, compound: str, n_labels: int
+    ) -> Optional[pd.DataFrame]:
         """Get concentrations of all isotopomers that carry n labels."""
         isotopomers = self.model.get_compound_isotopomers_with_n_labels(
             compound=compound,
@@ -194,7 +204,8 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         """Plot all total concentrations."""
         compounds = sorted(
-            [f"{i}__total" for i in self.model.label_compounds] + self.model.nonlabel_compounds
+            [f"{i}__total" for i in self.model.label_compounds]
+            + self.model.nonlabel_compounds
         )
         y = self.get_full_results_df(concatenated=True)
         if y is None:
@@ -219,14 +230,20 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
             title_kwargs=title_kwargs,
         )
 
-    def _calculate_label_distribution(self, *, compound: str, relative: bool) -> Optional[Array]:
+    def _calculate_label_distribution(
+        self, *, compound: str, relative: bool
+    ) -> Optional[Array]:
         """Calculate the label distribution of a compound."""
         total_concentration = self.get_total_concentration(compound=compound)
         if total_concentration is None:
             return None
         concentrations = []
-        for position in range(self.model.get_compound_number_of_label_positions(compound=compound)):
-            concentration = self.get_concentration_at_positions(compound=compound, positions=position)
+        for position in range(
+            self.model.get_compound_number_of_label_positions(compound=compound)
+        ):
+            concentration = self.get_concentration_at_positions(
+                compound=compound, positions=position
+            )
             if concentration is None:
                 return None
             if relative:
@@ -313,7 +330,12 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
             for compound in compounds
         ]
         legend_groups = [
-            [f"Pos {i}" for i in range(self.model.get_compound_number_of_label_positions(compound=compound))]
+            [
+                f"Pos {i}"
+                for i in range(
+                    self.model.get_compound_number_of_label_positions(compound=compound)
+                )
+            ]
             for compound in compounds
         ]
         if ylabels is None and relative:
@@ -376,7 +398,12 @@ class _LabelSimulate(_BaseRateSimulator[LabelModel]):
             for compound in base_compounds
         ]
         legend_groups = [
-            [f"Pos {i}" for i in range(self.model.get_compound_number_of_label_positions(compound=compound))]
+            [
+                f"Pos {i}"
+                for i in range(
+                    self.model.get_compound_number_of_label_positions(compound=compound)
+                )
+            ]
             for compound in base_compounds
         ]
         if ylabels is None and relative:
