@@ -17,6 +17,7 @@ from ..models import LinearLabelModel as _LinearLabelModel
 from . import _BaseSimulator
 
 
+
 class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
     """Simulator for LinearLabelModels."""
 
@@ -115,6 +116,14 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
             return None
         return cast(Array, res.loc[:, compounds].values)
 
+    def _make_legend_labels(self, compound: str, initial_index: int) -> list[str]:
+        return [
+            f"Pos {i}"
+            for i in range(
+                initial_index, len(self.model.isotopomers[compound]) + initial_index
+            )
+        ]
+
     def plot_label_distribution(
         self,
         compound: str,
@@ -133,13 +142,14 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         tick_kwargs: Optional[Dict[str, Any]] = None,
         label_kwargs: Optional[Dict[str, Any]] = None,
         title_kwargs: Optional[Dict[str, Any]] = None,
+        initial_index: int = 0,
     ) -> Tuple[Figure, Axis]:
         """Plot label distribution of a compound."""
         if ylabel is None and relative:
             ylabel = "Relative concentration"
         x = self.get_time()
         y = self.get_label_distribution(compound=compound)
-        legend = [f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))]
+        legend = self._make_legend_labels(compound, initial_index)
         if title is None:
             title = compound
         return plot(
@@ -182,6 +192,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         tick_kwargs: Optional[Dict[str, Any]] = None,
         label_kwargs: Optional[Dict[str, Any]] = None,
         title_kwargs: Optional[Dict[str, Any]] = None,
+        initial_index: int = 0,
     ) -> Tuple[Optional[Figure], Optional[Array]]:
         """Plot label distributions of multiple compounds on a grid."""
         time = self.get_time()
@@ -190,7 +201,8 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
             for compound in compounds
         ]
         legend_groups = [
-            [f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))]
+
+            self._make_legend_labels(compound, initial_index)
             for compound in compounds
         ]
         if ylabels is None and relative:
@@ -239,6 +251,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         tick_kwargs: Optional[Dict[str, Any]] = None,
         label_kwargs: Optional[Dict[str, Any]] = None,
         title_kwargs: Optional[Dict[str, Any]] = None,
+        initial_index: int = 0,
     ) -> Tuple[Optional[Figure], Optional[Array]]:
         """Plot label distributions of all compounds on a grid."""
         time = self.get_time()
@@ -248,7 +261,8 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
             for compound in compounds
         ]
         legend_groups = [
-            [f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))]
+
+            self._make_legend_labels(compound, initial_index)
             for compound in compounds
         ]
         if ylabels is None and relative:
